[![Build Status](https://travis-ci.com/NFontrodona/Lazyparser.svg?token=kVsLPqgGYaJqBE1Jazyp&branch=master)](https://travis-ci.com/NFontrodona/Lazyparser)
[![Coverage Status](https://coveralls.io/repos/github/NFontrodona/Lazyparser/badge.svg?branch=master)](https://coveralls.io/github/NFontrodona/Lazyparser?branch=master)
[![License](https://img.shields.io/badge/License-Apache%202.0-blue.svg)](https://opensource.org/licenses/Apache-2.0)
![PyPI - Python Version](https://img.shields.io/pypi/pyversions/lazyparser.svg)

# Lazyparser README

## Description

The lazyparser module automates the parsing of arguments. 
This module is based on [argparse](https://docs.python.org/3.5/library/argparse.html) developped by Steven J. Bethard.

The lazyparser was written in ``python 3.5 `` with the version 1.4.0 of argparse.
It is compatible with ``python 3.5`` or higher.

## Documentation

The documentation is available on <https://nfontrodona.github.io/Lazyparser/lazyparser.html>.
The documentation was created with sphinx (v 1.7).
To build the documentation, clone the project repository, go in the `doc` folder and type :

```sh
make html
```

This will create a folder `doc/build/html`. This folder will contain a file named ``index.html``. Double click on it to open the documentation with your web browser. 


## Installation

To install lazyparser, run :

```sh
pip install lazyparser
```
